// @ts-check
// Note: type annotations allow type checking and IDEs autocompletion

const lightCodeTheme = require('prism-react-renderer/themes/github');
const darkCodeTheme = require('prism-react-renderer/themes/dracula');

/** @type {import('@docusaurus/types').Config} */
const config = {
  title: 'Lydra | Artisans DevOps',
  tagline: 'Nous aidons les entreprises du numérique à déployer leurs applications web rapidement et sans coupure de service.',
  url: process.env.DOCUSAURUS_URL || 'https://new.lydra.fr"',
  baseUrl: process.env.DOCUSAURUS_BASEURL || '/',
  onBrokenLinks: 'throw',
  onBrokenMarkdownLinks: 'warn',
  favicon: 'img/favicon.png',
  organizationName: 'Lydra/www', // Usually your GitHub org/user name.
  projectName: 'Site lydra.fr', // Usually your repo name.

  i18n: {
    defaultLocale: 'fr',
    locales: ['fr'],
  },

  presets: [
    [
      'classic',
      /** @type {import('@docusaurus/preset-classic').Options} */
      ({
        docs: false,
        blog: {
          showReadingTime: true,
          // Please change this to your repo.
          // Remove this to remove the "edit this page" links.
          editUrl:
            'https://github.com/facebook/docusaurus/tree/main/packages/create-docusaurus/templates/shared/',
        },
        theme: {
          customCss: require.resolve('./src/css/custom.css'),
        },
      }),
    ],
  ],

  themeConfig:
    /** @type {import('@docusaurus/preset-classic').ThemeConfig} */
    ({
      colorMode: {
        defaultMode: 'dark',
        respectPrefersColorScheme: false,
      },
      navbar: {
        hideOnScroll: true,
        logo: {
          alt: 'Lydra Logo',
          src: 'img/logo_lydra.svg',
        },
        items: [
          {
            to: '/', 
            label: 'Home', 
            position: 'right'
          },
          {
            type: 'dropdown',
            label: 'DevOps',
            position: 'right',
            items: [
              {
                label: '📻 Le Podcast',
                href: 'https://lydra.fr/radio-devops/',
              },
              {
                label: 'Les Compagnons',
                href: 'https://www.compagnons-devops.fr/',
              },
            ],
          },
          {
            to: 'https://www.compagnons-devops.fr/mentor', 
            label: '🎓  Mentorat', 
            position: 'right'
          },
          {
            type: 'dropdown',
            label: 'Qui sommes nous ?',
            position: 'right',
            items: [
              {
                label: 'L\'équipe',
                href: '#',
              },
              {
                label: 'Nos inspirations',
                href: 'https://lydra.fr/nos-inspirations/',
              },
              {
                label: 'Nos Services',
                href: 'https://lydra.fr/nos-services/',
              },
              {
                label: 'Contact',
                href: '#',
              },
            ],
          },
          {
            to: '/blog', 
            label: '📰  Blog', 
            position: 'right'
          },
        ],
      },
      footer: {
        style: 'dark',
        links: [
          {
            title: 'Community',
            items: [
              {
                label: 'Stack Overflow',
                href: 'https://stackoverflow.com/questions/tagged/docusaurus',
              },
              {
                label: 'Discord',
                href: 'https://discordapp.com/invite/docusaurus',
              },
              {
                label: 'Twitter',
                href: 'https://twitter.com/docusaurus',
              },
            ],
          },
          {
            title: 'More',
            items: [
              {
                label: 'Blog',
                to: '/blog',
              },
              {
                label: 'GitHub',
                href: 'https://github.com/facebook/docusaurus',
              },
            ],
          },
        ],
        copyright: `Copyright © ${new Date().getFullYear()} Lydra. Tous droits réservés. `,
      },
      prism: {
        theme: lightCodeTheme,
        darkTheme: darkCodeTheme,
      },
    }),
};

module.exports = config;
